@@ -24,6 +24,14 @@
 #include <config.h>
 #endif
 
+/**
+ * SECTION:glade-command
+ * @Short_Description: An event filter to implement the Undo/Redo stack.
+ *
+ * The Glade Command api allows us to view user actions as items and execute 
+ * and undo those items; each #GladeProject has its own Undo/Redo stack.
+ */
+
 #include <gtk/gtk.h>
 #include <string.h>
 #include <glib/gi18n-lib.h>
@@ -197,7 +205,7 @@ glade_command_execute (GladeCommand *command)
  *
  * Undo the effects of @command
  *
- * Returns whether the command was successfully reversed
+ * Returns: whether the command was successfully reversed
  */
 gboolean
 glade_command_undo (GladeCommand *command)
@@ -356,8 +364,9 @@ glade_command_set_property_execute (GladeCommand *cmd)
 #if 0
 		{
 			gchar *str =
-				glade_property_class_make_string_from_gvalue 
-				(sdata->property->klass, &new_value);
+				glade_widget_adaptor_string_from_value
+				(GLADE_WIDGET_ADAPTOR (sdata->property->klass->handle),
+				 sdata->property->klass, &new_value);
 
 			g_print ("Setting %s property of %s to %s (sumode: %d)\n",
 				 sdata->property->klass->id,
@@ -542,8 +551,10 @@ glade_command_set_property_description (GladeCommandSetProperty *me)
 	else 
 	{
 		sdata = me->sdata->data;
-		value_name = glade_property_class_make_string_from_gvalue (sdata->property->klass, 
-									   sdata->new_value);
+		value_name = glade_widget_adaptor_string_from_value
+			(GLADE_WIDGET_ADAPTOR (sdata->property->klass->handle),
+			 sdata->property->klass, sdata->new_value);
+
 		if (!value_name || strlen (value_name) > MAX_UNDO_MENU_ITEM_VALUE_LEN
 		    || strchr (value_name, '_')) {
 			description = g_strdup_printf (_("Setting %s of %s"),
@@ -1539,7 +1550,7 @@ glade_command_clipboard_add_remove_collapse (GladeCommand *this_cmd, GladeComman
  * Creates a new widget using @adaptor and put in place of the @placeholder
  * in the @project
  *
- * Returns the newly created widget.
+ * Returns: the newly created widget.
  */
 GladeWidget*
 glade_command_create(GladeWidgetAdaptor *adaptor, GladeWidget *parent, GladePlaceholder *placeholder, GladeProject *project)
@@ -1572,7 +1583,6 @@ glade_command_create(GladeWidgetAdaptor *adaptor, GladeWidget *parent, GladePlac
 /**
  * glade_command_delete:
  * @widgets: a #GList of #GladeWidgets
- * @return_placeholders: whether or not to return a list of placehodlers
  *
  * Performs a delete command on the list of widgets.
  */
@@ -1858,18 +1868,18 @@ glade_command_remove_signal (GladeWidget *glade_widget, const GladeSignal *signa
 /**
  * glade_command_change_signal:
  * @glade_widget: a #GladeWidget
- * @old: a #GladeSignal
- * @new: a #GladeSignal
+ * @old_signal: a #GladeSignal
+ * @new_signal: a #GladeSignal
  *
  * TODO: write me
  */
 void
 glade_command_change_signal	(GladeWidget *glade_widget, 
-				 const GladeSignal *old, 
+				 const GladeSignal *old_signal, 
 				 const GladeSignal *new_signal)
 {
 	glade_command_add_remove_change_signal 
-		(glade_widget, old, new_signal, GLADE_CHANGE);
+		(glade_widget, old_signal, new_signal, GLADE_CHANGE);
 }
 
 /******************************************************************************
