@@ -121,6 +121,8 @@ struct _GladeProjectPrivate
 			        */
 			 
 	time_t  mtime;         /* last UTC modification time of file, or 0 if it could not be read */
+
+	GladeProjectFormat format; /* file format */
 };
 
 
@@ -128,10 +130,6 @@ static guint              glade_project_signals[LAST_SIGNAL] = {0};
 
 static GladeIDAllocator  *unsaved_number_allocator = NULL;
 
-static gboolean glade_project_load_from_interface (GladeProject   *project,
-						   GladeInterface *interface,
-						   const gchar    *path);
-
 
 G_DEFINE_TYPE (GladeProject, glade_project, G_TYPE_OBJECT)
 
@@ -491,7 +489,9 @@ glade_project_init (GladeProject *project)
 						 g_direct_equal, 
 						 NULL, g_free);
 
-	priv->unsaved_number = glade_id_allocator_allocate (get_unsaved_number_allocator ());	
+	priv->unsaved_number = glade_id_allocator_allocate (get_unsaved_number_allocator ());
+
+	priv->format = GLADE_PROJECT_FORMAT_LIBGLADE;
 }
 
 static void
@@ -764,38 +764,181 @@ glade_project_new (void)
 	return g_object_new (GLADE_TYPE_PROJECT, NULL);
 }
 
+
+static void 
+glade_project_fix_object_props (GladeProject *project)
+{
+	GList         *l, *ll;
+	GValue        *value;
+	GladeWidget   *gwidget;
+	GladeProperty *property;
+	gchar         *txt;
+
+	for (l = project->priv->objects; l; l = l->next)
+	{
+		gwidget = glade_widget_get_from_gobject (l->data);
+
+		for (ll = gwidget->properties; ll; ll = ll->next)
+		{
+			property = GLADE_PROPERTY (ll->data);
+
+			if (glade_property_class_is_object (property->klass) &&
+			    (txt = g_object_get_data (G_OBJECT (property), 
+						      "glade-loaded-object")) != NULL)
+			{
+				/* Parse the object list and set the property to it
+				 * (this magicly works for both objects & object lists)
+				 */
+				value = glade_property_class_make_gvalue_from_string
+					(property->klass, txt, project);
+				
+				glade_property_set_value (property, value);
+				
+				g_value_unset (value);
+				g_free (value);
+				
+				g_object_set_data (G_OBJECT (property), 
+						   "glade-loaded-object", NULL);
+			}
+		}
+	}
+}
+
+static gboolean
+loadable_interface (GladeXmlNode *root_node, const gchar *path)
+{
+
+	GString      *string = g_string_new (NULL);
+	GladeXmlNode *node;
+	gchar        *required_lib;
+	gboolean      loadable = TRUE;
+
+	for (node = glade_xml_node_get_children (root_node); 
+	     node; node = glade_xml_node_next (node))
+	{
+		/* Skip "requires" tags */
+		if (!glade_xml_node_verify_silent (node, GLADE_XML_TAG_REQUIRES))
+			continue;
+
+		if ((required_lib = 
+		     glade_xml_get_property_string_required (node, GLADE_XML_TAG_LIB, 
+							     NULL)) != NULL)
+		{
+			if (!glade_catalog_is_loaded (required_lib))
+			{
+				if (!loadable)
+					g_string_append (string, ", ");
+
+				g_string_append (string, required_lib);
+				loadable = FALSE;
+			}
+			
+		}
+	}
+
+	if (!loadable)
+		glade_util_ui_message (glade_app_get_window(),
+				       GLADE_UI_ERROR,
+				       _("Failed to load %s.\n"
+					 "The following required catalogs are unavailable: %s"),
+				       path, string->str);
+	g_string_free (string, TRUE);
+	return loadable;
+}
+
+static void
+glade_project_read_comment (GladeProject *project, GladeXmlDoc *doc)
+{
+	/* TODO Write me !! Find out how to extract root level comments 
+	 * with libxml2 !!! 
+	 */
+}
+
+
 gboolean
 glade_project_load_from_file (GladeProject *project, const gchar *path)
 {
-	GladeInterface *interface;
-	
-	g_return_val_if_fail (GLADE_IS_PROJECT (project), FALSE); 
-	g_return_val_if_fail (path != NULL, FALSE);
+	GladeXmlContext *context;
+	GladeXmlDoc     *doc;
+	GladeXmlNode    *root;
+	GladeXmlNode    *node;
+	GladeWidget     *widget;
 
-	interface = glade_parser_interface_new_from_file (path, NULL);
+	project->priv->selection = NULL;
+	project->priv->objects = NULL;
+	project->priv->loading = TRUE;
 
-	if (interface != NULL)
+	project->priv->path = glade_util_canonical_path (path);	
+
+	/* get the context & root node of the catalog file */
+	if (!(context = 
+	      glade_xml_context_new_from_path (path,
+					       NULL, 
+					       NULL)))
 	{
-		if (!glade_project_load_from_interface (project, interface, path))
-		{
-			glade_parser_interface_destroy (interface);
-			return FALSE;
-		}
-		glade_parser_interface_destroy (interface);
+		g_warning ("Couldn't open glade file [%s].", path);
+		return FALSE;
 	}
+
+	doc  = glade_xml_context_get_doc (context);
+	root = glade_xml_doc_get_root (doc);
+
+	if (glade_xml_node_verify_silent (root, GLADE_XML_TAG_LIBGLADE_PROJECT))
+		project->priv->format = GLADE_PROJECT_FORMAT_LIBGLADE;
+	else if (glade_xml_node_verify_silent (root, GLADE_XML_TAG_BUILDER_PROJECT))
+		project->priv->format = GLADE_PROJECT_FORMAT_GTKBUILDER;
 	else
 	{
+		g_warning ("Couldnt determine project format, skipping %s", path);
+		glade_xml_context_free (context);
 		return FALSE;
 	}
 
+	/* XXX Need to load project->priv->comment ! */
+	glade_project_read_comment (project, doc);
+
+	if (loadable_interface (root, path) == FALSE)
+	{
+		glade_xml_context_free (context);
+		return FALSE;
+	}
+
+	for (node = glade_xml_node_get_children (root); 
+	     node; node = glade_xml_node_next (node))
+	{
+		/* Skip "requires" tags */
+		if (!glade_xml_node_verify_silent
+		    (node, GLADE_XML_TAG_WIDGET (project->priv->format)))
+			continue;
+
+		if ((widget = glade_widget_read (project, NULL, node, NULL)) != NULL)
+			glade_project_add_object (project, NULL, widget->object);
+	}
+
 	if (glade_util_file_is_writeable (project->priv->path) == FALSE)
 		glade_project_set_readonly (project, TRUE);
 
-	project->priv->modified = FALSE;
-		
+	/* Finished with the xml context */
+	glade_xml_context_free (context);
+
 	project->priv->mtime = glade_util_get_file_mtime (project->priv->path, NULL);
 
+	/* Reset project status here too so that you get a clean
+	 * slate after calling glade_project_open().
+	 */
+	project->priv->modified = FALSE;
+	project->priv->loading = FALSE;
+
+	/* Emit "parse-finished" signal */
+	g_signal_emit (project, glade_project_signals [PARSE_FINISHED], 0);
+	
+	/* Now we have to loop over all the object properties
+	 * and fix'em all ('cause they probably weren't found)
+	 */
+	glade_project_fix_object_props (project);
+
 	return TRUE;
+
 }
 
 
@@ -866,8 +1009,9 @@ gp_sync_resources (GladeProject *project,
 
 			glade_property_get_value (property, &value);
 			
-			if ((resource = glade_property_class_make_string_from_gvalue
-			     (property->klass, &value)) != NULL)
+			if ((resource = glade_widget_adaptor_string_from_value
+			     (GLADE_WIDGET_ADAPTOR (property->klass->handle),
+			      property->klass, &value)) != NULL)
 			{
 				full_resource = glade_project_resource_fullpath
 					(prev_project ? prev_project : project, resource);
@@ -937,6 +1081,7 @@ glade_project_add_object (GladeProject *project,
 	if (GLADE_IS_PLACEHOLDER (object)) 
 		return;
 
+
 	/* Only widgets accounted for in the catalog or widgets declared
 	 * in the plugin with glade_widget_new_for_internal_child () are
 	 * usefull in the project.
@@ -948,6 +1093,7 @@ glade_project_add_object (GladeProject *project,
 	if (glade_project_has_object (project, object))
 		return;
 
+
 	/* Police widget names here (just rename them on the way in the project)
 	 */
 	if (glade_project_get_widget_by_name (project, gwidget->name) != NULL)
@@ -1000,7 +1146,7 @@ glade_project_add_object (GladeProject *project,
  * @project: the #GladeProject the widget is added to
  * @object: the #GObject to search
  *
- * Returns whether this object is in this project.
+ * Returns: whether this object is in this project.
  */
 gboolean
 glade_project_has_object (GladeProject *project, GObject *object)
@@ -1515,39 +1661,43 @@ glade_project_update_comment (GladeProject *project)
 	g_strfreev (lines);
 }
 
-/**
- * glade_project_write:
- * @project: a #GladeProject
- * 
- * Returns: a libglade's GladeInterface representation of the
- *          project and its contents
- */
-static GladeInterface *
+
+static GladeXmlContext *
 glade_project_write (GladeProject *project)
 {
-	GladeInterface  *interface;
-	GList           *required, *list, *tops = NULL;
-	gchar          **strv = NULL;
-	guint            i;
+	GladeXmlContext *context;
+	GladeXmlDoc     *doc;
+	GladeXmlNode    *root, *req_node, *comment_node;
+	GList           *required, *list;
 
-	interface = glade_parser_interface_new ();
+	doc     = glade_xml_doc_new ();
+	context = glade_xml_context_new (doc, NULL);
+	root    = glade_xml_node_new (context, GLADE_XML_TAG_PROJECT (project->priv->format));
+	glade_xml_doc_set_root (doc, root);
+
+	glade_project_update_comment (project);
+/* 	comment_node = glade_xml_node_new_comment (context, project->priv->comment); */
+
+	/* XXX Need to append this to the doc ! not the ROOT !
+	   glade_xml_node_append_child (root, comment_node); */
 
 	if ((required = glade_project_required_libs (project)) != NULL)
 	{
-		strv = g_malloc0 (g_list_length (required) * sizeof (char *));
-		for (i = 0, list = required; list; i++, list = list->next)
-			strv[i] = list->data; /* list->data is allocated for us */
-
-		interface->n_requires = g_list_length (required);
-		interface->requires   = strv;
-
+		for (list = required; list; list = list->next)
+		{
+			req_node = glade_xml_node_new (context, GLADE_XML_TAG_REQUIRES);
+			glade_xml_node_append_child (root, req_node);
+			glade_xml_node_set_property_string (req_node, 
+							    GLADE_XML_TAG_LIB, 
+							    (gchar *)list->data);
+		}
+		g_list_foreach (required, (GFunc)g_free, NULL);
 		g_list_free (required);
 	}
 
-	for (i = 0, list = project->priv->objects; list; list = list->next)
+	for (list = project->priv->objects; list; list = list->next)
 	{
 		GladeWidget *widget;
-		GladeWidgetInfo *info;
 
 		widget = glade_widget_get_from_gobject (list->data);
 
@@ -1556,146 +1706,10 @@ glade_project_write (GladeProject *project)
 		 * care of appending its children.
 		 */
 		if (widget->parent == NULL)
-		{
-			info = glade_widget_write (widget, interface);
-			if (!info)
-				return NULL;
-
-			tops = g_list_prepend (tops, info);
-			++i;
-		}
+			glade_widget_write (widget, context, root);
 	}
-	interface->n_toplevels = i;
-        interface->toplevels = (GladeWidgetInfo **) g_new (GladeWidgetInfo *, i);
-        for (i = 0, list = tops; list; list = list->next, ++i)
-            interface->toplevels[i] = list->data;
-
-	g_list_free (tops);
-
-	glade_project_update_comment (project);
-	interface->comment = g_strdup (project->priv->comment);
 	
-	return interface;
-}
-
-static gboolean
-loadable_interface (GladeInterface *interface, const gchar *path)
-{
-	GString *string = g_string_new (NULL);
-	gboolean loadable = TRUE;
-	guint i;
-
-	/* Check for required plugins here
-	 */
-	for (i = 0; i < interface->n_requires; i++)
-		if (!glade_catalog_is_loaded (interface->requires[i]))
-		{
-			g_string_append (string, interface->requires[i]);
-			loadable = FALSE;
-		}
-
-	if (loadable == FALSE)
-		glade_util_ui_message (glade_app_get_window(),
-				       GLADE_UI_ERROR,
-				       _("Failed to load %s.\n"
-					 "The following required catalogs are unavailable: %s"),
-				       path, string->str);
-	g_string_free (string, TRUE);
-	return loadable;
-}
-
-static void 
-glade_project_fix_object_props (GladeProject *project)
-{
-	GList         *l, *ll;
-	GValue        *value;
-	GladeWidget   *gwidget;
-	GladeProperty *property;
-	gchar         *txt;
-
-	for (l = project->priv->objects; l; l = l->next)
-	{
-		gwidget = glade_widget_get_from_gobject (l->data);
-
-		for (ll = gwidget->properties; ll; ll = ll->next)
-		{
-			property = GLADE_PROPERTY (ll->data);
-
-			if (glade_property_class_is_object (property->klass) &&
-			    (txt = g_object_get_data (G_OBJECT (property), 
-						      "glade-loaded-object")) != NULL)
-			{
-				/* Parse the object list and set the property to it
-				 * (this magicly works for both objects & object lists)
-				 */
-				value = glade_property_class_make_gvalue_from_string
-					(property->klass, txt, project);
-				
-				glade_property_set_value (property, value);
-				
-				g_value_unset (value);
-				g_free (value);
-				
-				g_object_set_data (G_OBJECT (property), 
-						   "glade-loaded-object", NULL);
-			}
-		}
-	}
-}
-
-static gboolean
-glade_project_load_from_interface (GladeProject   *project,
-				   GladeInterface *interface,
-				   const gchar    *path)
-{
-	GladeWidget  *widget;
-	guint         i;
-
-	g_return_val_if_fail (project != NULL, FALSE);
-	g_return_val_if_fail (interface != NULL, FALSE);
-	g_return_val_if_fail (path != NULL, FALSE);
-
-	if (loadable_interface (interface, path) == FALSE)
-		return FALSE;
-
-	project->priv->path = glade_util_canonical_path (path);
-	
-	project->priv->selection = NULL;
-	project->priv->objects = NULL;
-	project->priv->loading = TRUE;
-
-	/* keep a comment */
-	if (interface->comment)
-		project->priv->comment = g_strdup (interface->comment);
-	
-	for (i = 0; i < interface->n_toplevels; ++i)
-	{
-		widget = glade_widget_read ((gpointer) project, interface->toplevels[i]);
-		
-		if (!widget)
-		{
-			g_warning ("Failed to read a <widget> tag");
-			continue;
-		}
-
-		glade_project_add_object (project, NULL, widget->object);
-	}
-
-	/* Reset project status here too so that you get a clean
-	 * slate after calling glade_project_open().
-	 */
-	project->priv->modified = FALSE;
-	project->priv->loading = FALSE;
-
-	/* Emit "parse-finished" signal */
-	g_signal_emit (project, glade_project_signals [PARSE_FINISHED], 0);
-	
-	/* Now we have to loop over all the object properties
-	 * and fix'em all ('cause they probably weren't found)
-	 */
-	glade_project_fix_object_props (project);
-	
-	return TRUE;	
+	return context;
 }
 
 /**
@@ -1772,22 +1786,15 @@ glade_project_move_resources (GladeProject *project,
 gboolean
 glade_project_save (GladeProject *project, const gchar *path, GError **error)
 {
-	GladeInterface *interface;
-	gboolean        ret;
-	gchar          *canonical_path;
+	GladeXmlContext *context;
+	GladeXmlDoc     *doc;
+	gchar           *canonical_path;
+	gint             ret;
 
-	g_return_val_if_fail (GLADE_IS_PROJECT (project), FALSE);
-	g_return_val_if_fail (path != NULL, FALSE);
-
-	interface = glade_project_write (project);
-	if (!interface)
-	{
-		g_warning ("Could not write glade document\n");
-		return FALSE;
-	}
-
-	ret = glade_parser_interface_dump (interface, path, error);
-	glade_parser_interface_destroy (interface);
+	context = glade_project_write (project);
+	doc     = glade_xml_context_get_doc (context);
+	ret     = glade_xml_doc_save (doc, path);
+	glade_xml_context_destroy (context);
 
 	canonical_path = glade_util_canonical_path (path);
 	g_assert (canonical_path);
@@ -1827,7 +1834,7 @@ glade_project_save (GladeProject *project, const gchar *path, GError **error)
 
 	g_free (canonical_path);
 
-	return ret;
+	return ret > 0;
 }
 
 
@@ -2333,3 +2340,18 @@ glade_project_get_modified (GladeProject *project)
 	return project->priv->modified;
 }
 
+void
+glade_project_set_format (GladeProject *project, GladeProjectFormat format)
+{
+	g_return_if_fail (GLADE_IS_PROJECT (project));
+
+	project->priv->format = format; 
+}
+
+GladeProjectFormat
+glade_project_get_format (GladeProject *project)
+{
+	g_return_val_if_fail (GLADE_IS_PROJECT (project), -1);
+
+	return project->priv->format;
+}
