@@ -4,6 +4,7 @@
 
 #include <gladeui/glade-widget.h>
 #include <gladeui/glade-command.h>
+#include <gladeui/glade-utils.h>
 
 G_BEGIN_DECLS
 
@@ -17,6 +18,13 @@ G_BEGIN_DECLS
 typedef struct _GladeProjectPrivate  GladeProjectPrivate;
 typedef struct _GladeProjectClass    GladeProjectClass;
 
+
+typedef enum
+{
+	GLADE_PROJECT_FORMAT_LIBGLADE,
+	GLADE_PROJECT_FORMAT_GTKBUILDER
+} GladeProjectFormat;
+
 struct _GladeProject
 {
 	GObject parent_instance;
@@ -110,8 +118,6 @@ char          *glade_project_new_widget_name     (GladeProject *project, const c
 void           glade_project_widget_name_changed (GladeProject *project, GladeWidget *widget,
 						 const char   *old_name);
 
-GtkTooltips   *glade_project_get_tooltips        (GladeProject *project);
-
 /* Selection */
 
 gboolean       glade_project_is_selected         (GladeProject *project,
@@ -160,6 +166,10 @@ void           glade_project_set_instance_count   (GladeProject *project, guint
 
 gboolean       glade_project_get_modified         (GladeProject *project);
 
+void           glade_project_set_format      	  (GladeProject *project, GladeProjectFormat format);
+
+GladeProjectFormat glade_project_get_format  	  (GladeProject *project);
+
 G_END_DECLS
 
 #endif /* __GLADE_PROJECT_H__ */
