@@ -8,13 +8,23 @@
  *   Chema Celorio <chema@gnome.org>
  */
 
+/**
+ * SECTION:glade-xml-utils
+ * @Title: Xml Utils
+ * @Short_Description: An api to read and write xml.
+ *
+ * You may need these tools if you are implementing #GladeReadWidgetFunc
+ * and/or #GladeWriteWidgetFunc on your #GladeWidgetAdaptor to read
+ * and write widgets in custom ways
+ */
+
+
 #include "config.h"
 
 #include <string.h>
 #include <glib.h>
 #include <errno.h>
 
-#include "glade.h"
 #include "glade-xml-utils.h"
 
 #include <libxml/tree.h>
@@ -22,8 +32,6 @@
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
 
-#include "glade-utils.h"
-
 struct _GladeXmlNode
 {
 	xmlNodePtr node;
@@ -89,9 +97,9 @@ glade_xml_set_value (GladeXmlNode *node_in, const gchar *name, const gchar *val)
  * glade_xml_get_content:
  * @node_in: a #GladeXmlNode
  *
- * Returns a string containing the content of @node_in.
- * Note: It is the caller's responsibility to free the memory used by this 
- * string.
+ * Gets a string containing the content of @node_in.
+ *
+ * Returns: A newly allocated string
  */
 gchar *
 glade_xml_get_content (GladeXmlNode *node_in)
@@ -205,7 +213,7 @@ glade_xml_get_value_int (GladeXmlNode *node_in, const gchar *name, gint *val)
                 return FALSE;
 
         errno = 0;
-        i = glade_util_ascii_strtoll (value, &endptr, 10);
+        i = g_ascii_strtoll (value, &endptr, 10);
         if (errno != 0 || (i == 0 && endptr == value)) {
                 g_free (value);
                 return FALSE;
@@ -235,7 +243,7 @@ glade_xml_get_value_int_required (GladeXmlNode *node, const gchar *name, gint  *
 	ret = glade_xml_get_value_int (node, name, val);
 
 	if (ret == FALSE)
-		g_warning ("The file did not contained the required value \"%s\"\n"
+		g_warning ("The file did not contain the required value \"%s\"\n"
 			   "Under the \"%s\" tag.", name, glade_xml_node_get_name (node));
 			
 	return ret;
@@ -390,7 +398,7 @@ glade_xml_get_property_int (GladeXmlNode *node_in,
 	if ((value = glade_xml_get_property (node, name)) == NULL)
 		return _default;
 
-	retval = atoi (value);
+	retval = g_ascii_strtoll (value, NULL, 10);
 	
 	g_free (value);
 
@@ -428,10 +436,10 @@ glade_xml_get_value_string_required (GladeXmlNode *node_in,
 	if (value == NULL)
 	{
 		if (xtra == NULL)
-			g_warning ("The file did not contained the required value \"%s\"\n"
+			g_warning ("The file did not contain the required value \"%s\"\n"
 				   "Under the \"%s\" tag.", name, node->name);
 		else
-			g_warning ("The file did not contained the required value \"%s\"\n"
+			g_warning ("The file did not contain the required value \"%s\"\n"
 				   "Under the \"%s\" tag (%s).", name, node->name, xtra);
 	}
 
@@ -467,10 +475,10 @@ glade_xml_get_property_string_required (GladeXmlNode *node_in,
 	if (value == NULL)
 	{
 		if (xtra == NULL)
-			g_warning ("The file did not contained the required property \"%s\"\n"
+			g_warning ("The file did not contain the required property \"%s\"\n"
 				   "Under the \"%s\" tag.", name, node->name);
 		else
-			g_warning ("The file did not contained the required property \"%s\"\n"
+			g_warning ("The file did not contain the required property \"%s\"\n"
 				   "Under the \"%s\" tag (%s).", name, node->name, xtra);
 	}
 	return value;
@@ -517,7 +525,7 @@ glade_xml_search_child_required (GladeXmlNode *node, const gchar* name)
 	child = glade_xml_search_child (node, name);
 
 	if (child == NULL)
-		g_warning ("The file did not contained the required tag \"%s\"\n"
+		g_warning ("The file did not contain the required tag \"%s\"\n"
 			   "Under the \"%s\" node.", name, glade_xml_node_get_name (node));
 
 	return child;
@@ -541,7 +549,7 @@ GladeXmlContext *
 glade_xml_context_new (GladeXmlDoc *doc, const gchar *name_space)
 {
 	/* We are not using the namespace now */
-	return glade_xml_context_new_real (doc, FALSE, NULL);
+	return glade_xml_context_new_real (doc, TRUE, NULL);
 }
 
 void
@@ -582,7 +590,7 @@ glade_xml_context_new_from_path (const gchar *full_path,
 	name_space = xmlSearchNsByHref (doc, doc->children, BAD_CAST(nspace));
 	if (name_space == NULL && nspace != NULL)
 	{
-		g_warning ("The file did not contained the expected name space\n"
+		g_warning ("The file did not contain the expected name space\n"
 			   "Expected \"%s\" [%s]",
 			   nspace, full_path);
 		xmlFreeDoc (doc);
@@ -590,9 +598,10 @@ glade_xml_context_new_from_path (const gchar *full_path,
 	}
 
 	root = xmlDocGetRootElement(doc);
-	if ((root->name == NULL) || (xmlStrcmp (root->name, BAD_CAST(root_name)) !=0 ))
+	if (root_name != NULL &&
+	    ((root->name == NULL) || (xmlStrcmp (root->name, BAD_CAST(root_name)) != 0)))
 	{
-		g_warning ("The file did not contained the expected root name\n"
+		g_warning ("The file did not contain the expected root name\n"
 			   "Expected \"%s\", actual : \"%s\" [%s]",
 			   root_name, root->name, full_path);
 		xmlFreeDoc (doc);
@@ -633,6 +642,17 @@ glade_xml_node_append_child (GladeXmlNode *node_in, GladeXmlNode *child_in)
 	xmlAddChild (node, child);
 }
 
+void
+glade_xml_node_remove (GladeXmlNode *node_in)
+{
+	xmlNodePtr node = (xmlNodePtr) node_in;
+	
+	g_return_if_fail (node  != NULL);
+	
+	xmlReplaceNode (node, NULL);
+}
+
+
 GladeXmlNode *
 glade_xml_node_new (GladeXmlContext *context, const gchar *name)
 {
@@ -641,6 +661,16 @@ glade_xml_node_new (GladeXmlContext *context, const gchar *name)
 
 	return (GladeXmlNode *) xmlNewDocNode ((xmlDocPtr) context->doc, context->ns, BAD_CAST(name), NULL);
 }
+
+GladeXmlNode * 
+glade_xml_node_new_comment (GladeXmlContext *context, const gchar *comment)
+{
+	g_return_val_if_fail (context != NULL, NULL);
+	g_return_val_if_fail (comment != NULL, NULL);
+
+	return (GladeXmlNode *) xmlNewDocComment ((xmlDocPtr) context->doc, BAD_CAST(comment));
+}
+
 					   
 void
 glade_xml_node_delete (GladeXmlNode *node)
@@ -654,8 +684,10 @@ glade_xml_context_get_doc (GladeXmlContext *context)
 	return context->doc;
 }
 
-static gboolean
-glade_libxml_node_is_comment (xmlNodePtr node) {
+gboolean
+glade_xml_node_is_comment (GladeXmlNode *node_in) 
+{
+	xmlNodePtr node = (xmlNodePtr) node_in;
 	if (node == NULL)
 		return FALSE;
 	if ((xmlStrcmp ( node->name, BAD_CAST("text")) == 0) ||
@@ -671,24 +703,41 @@ glade_xml_node_get_children (GladeXmlNode *node_in)
 	xmlNodePtr children;
 
 	children = node->children;
-	while (glade_libxml_node_is_comment (children))
+	while (glade_xml_node_is_comment ((GladeXmlNode *)children))
 		children = children->next;
 
 	return (GladeXmlNode *)children;
 }
 
+GladeXmlNode *
+glade_xml_node_get_children_with_comments (GladeXmlNode *node_in)
+{
+	xmlNodePtr node = (xmlNodePtr) node_in;
+
+	return (GladeXmlNode *)node->children;
+}
+
 GladeXmlNode *
 glade_xml_node_next (GladeXmlNode *node_in)
 {
 	xmlNodePtr node = (xmlNodePtr) node_in;
 
 	node = node->next;
-	while (glade_libxml_node_is_comment (node))
+	while (glade_xml_node_is_comment ((GladeXmlNode *)node))
 		node = node->next;
 
 	return (GladeXmlNode *)node;
 }
 
+GladeXmlNode *
+glade_xml_node_next_with_comments (GladeXmlNode *node_in)
+{
+	xmlNodePtr node = (xmlNodePtr) node_in;
+
+	return (GladeXmlNode *)node->next;
+}
+
+
 const gchar *
 glade_xml_node_get_name (GladeXmlNode *node_in)
 {
@@ -747,47 +796,14 @@ glade_xml_doc_get_root (GladeXmlDoc *doc)
 	return (GladeXmlNode *)node;
 }
 
-gchar *
-glade_xml_alloc_string(GladeInterface *interface, const gchar *string)
-{
-    gchar *s;
-
-    s = g_hash_table_lookup(interface->strings, string);
-    if (!s) {
-        s = g_strdup(string);
-        g_hash_table_insert(interface->strings, s, s);
-    }
-
-    return s;
-}
-
-gchar *
-glade_xml_alloc_propname(GladeInterface *interface, const gchar *string)
-{
-    static GString *norm_str;
-    guint i;
-
-    if (!norm_str)
-	norm_str = g_string_new_len(NULL, 64);
-
-    /* assign the string to norm_str */
-    g_string_assign(norm_str, string);
-    /* convert all dashes to underscores */
-    for (i = 0; i < norm_str->len; i++)
-	if (norm_str->str[i] == '-')
-	    norm_str->str[i] = '_';
-
-    return glade_xml_alloc_string(interface, norm_str->str);
-}
-
-
-void
+gboolean
 glade_xml_load_sym_from_node (GladeXmlNode     *node_in,
 			      GModule          *module,
 			      gchar            *tagname,
 			      gpointer         *sym_location)
 {
 	static GModule *self = NULL;
+	gboolean retval = FALSE;
 	gchar *buff;
 
 	if (!self) 
@@ -801,7 +817,7 @@ glade_xml_load_sym_from_node (GladeXmlNode     *node_in,
 				   "no module available to load it from !", 
 				   buff, tagname);
 			g_free (buff);
-			return;
+			return FALSE;
 		}
 
 		/* I use here a g_warning to signal these errors instead of a dialog 
@@ -816,10 +832,14 @@ glade_xml_load_sym_from_node (GladeXmlNode     *node_in,
 		 *
 		 * XXX http://bugzilla.gnome.org/show_bug.cgi?id=331797
 		 */
-		if (!g_module_symbol (module, buff, sym_location))
-			if (!g_module_symbol (self, buff, sym_location))
-				g_warning ("Could not find %s in %s or in global namespace\n",
-					   buff, g_module_name (module));
+		if (g_module_symbol (module, buff, sym_location) ||
+		    g_module_symbol (self, buff, sym_location))
+			retval = TRUE;
+		else
+			g_warning ("Could not find %s in %s or in global namespace\n",
+				   buff, g_module_name (module));
+
 		g_free (buff);
 	}
+	return retval;
 }
