@@ -1158,8 +1158,9 @@ open_cb (GtkAction *action, GladeWindow *window)
 	GtkWidget *filechooser;
 	gchar     *path = NULL, *default_path;
 
-	filechooser = glade_util_file_dialog_new (_("Open\342\200\246"), GTK_WINDOW (window),
-						   GLADE_FILE_DIALOG_ACTION_OPEN);
+	filechooser = glade_util_file_dialog_new (_("Open\342\200\246"), NULL,
+						  GTK_WINDOW (window),
+						  GLADE_FILE_DIALOG_ACTION_OPEN);
 
 
 	default_path = g_strdup (get_default_path (window));
@@ -1279,7 +1280,7 @@ save_as (GladeWindow *window)
 	if (project == NULL)
 		return;
 
-	filechooser = glade_util_file_dialog_new (_("Save As\342\200\246"),
+	filechooser = glade_util_file_dialog_new (_("Save As\342\200\246"), project,
 						  GTK_WINDOW (window),
 						  GLADE_FILE_DIALOG_ACTION_SAVE);
 
@@ -1454,7 +1455,7 @@ confirm_close_project (GladeWindow *window, GladeProject *project)
 			gchar *default_path;
 
 			filechooser =
-				glade_util_file_dialog_new (_("Save\342\200\246"),
+				glade_util_file_dialog_new (_("Save\342\200\246"), project,
 							    GTK_WINDOW (window),
 							    GLADE_FILE_DIALOG_ACTION_SAVE);
 	
@@ -2111,7 +2112,7 @@ about_cb (GtkAction *action, GladeWindow *window)
 	static const gchar copyright[] =
 		"Copyright \xc2\xa9 2001-2006 Ximian, Inc.\n"
 		"Copyright \xc2\xa9 2001-2006 Joaquin Cuenca Abela, Paolo Borelli, et al.\n"
-		"Copyright \xc2\xa9 2001-2008 Tristan Van Berkom, Juan Pablo Ugarte, et al.";
+		"Copyright \xc2\xa9 2001-2006 Tristan Van Berkom, Juan Pablo Ugarte, et al.";
 	
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "name", g_get_application_name (),
